Index — django-premailer 0.1.0 documentation

# Index

D | M | R | S | V

## D

django_premailer (module) django_premailer.models (module) | django_premailer.templatetags (module)

## M

major (django_premailer.version_info_t attribute) micro (django_premailer.version_info_t attribute) | minor (django_premailer.version_info_t attribute)

## R

releaselevel (django_premailer.version_info_t attribute)

## S

serial (django_premailer.version_info_t attribute)

## V

version_info_t (class in django_premailer)